==> eventbrite_api-7.x-1.0.tar.gz: eventbrite_api/theme/attendee.tpl.php <==
<fieldset>
  <legend>Personal details</legend>
  <div><label>Attendee ID:</label> <?php print $attendee['aid']; ?></div>
  <div><label>Prefix:</label> <?php print $attendee['prefix']; ?></div>
  <div><label>First name:</label> <?php print $attendee['first_name']; ?></div>
  <div><label>Last name:</label> <?php print $attendee['last_name']; ?></div>
  <div><label>Suffix:</label> <?php print $attendee['suffix']; ?></div>
  <div><label>Address:</label> <?php print $attendee['home_address']; ?></div>
  <div><label>Address 2:</label> <?php print $attendee['home_address_2']; ?></div>
  <div><label>City:</label> <?php print $attendee['home_city']; ?></div>
  <div><label>Region:</label> <?php print $attendee['home_region']; ?></div>
  <div><label>Postal code:</label> <?php print $attendee['home_postal_code']; ?></div>
  <div><label>Country:</label> <?php print $attendee['home_country']; ?></div>
  <div><label>Country code:</label> <?php print $attendee['home_country_code']; ?></div>
  <div><label>Home phone:</label> <?php print $attendee['home_phone']; ?></div>
  <div><label>Cell/mobile phone:</label> <?php print $attendee['cell_phone']; ?></div>
  <div><label>Birth date:</label> <?php print $attendee['birth_date']; ?></div>
  <div><label>Age:</label> <?php print $attendee['age']; ?></div>
  <div><label>Gender:</label> <?php print $attendee['gender']; ?></div>
</fieldset>

<fieldset>
  <legend>Work details</legend>
  <div><label>Company:</label> <?php print $attendee['company']; ?></div>
  <div><label>Address:</label> <?php print $attendee['work_address']; ?></div>
  <div><label>Address 2:</label> <?php print $attendee['work_address_2']; ?></div>
  <div><label>City:</label> <?php print $attendee['work_city']; ?></div>
  <div><label>Region:</label> <?php print $attendee['work_region']; ?></div>
  <div><label>Postal code:</label> <?php print $attendee['work_postal_code']; ?></div>
  <div><label>Country:</label> <?php print $attendee['work_country']; ?></div>
  <div><label>Country code:</label> <?php print $attendee['work_country_code']; ?></div>
  <div><label>Phone:</label> <?php print $attendee['work_phone']; ?></div>
  <div><label>Blog:</label> <?php print $attendee['blog']; ?></div>
  <div><label>Email:</label> <?php print $attendee['email']; ?></div>
  <div><label>Job title:</label> <?php print $attendee['job_title']; ?></div>
</fieldset>

<fieldset>
  <legend>Order details</legend>
  <div><label>Order ID:</label> <?php print $attendee['orid']; ?></div>
  <div><label>Event ID:</label> <?php print $attendee['eid']; ?></div>
  <div><label>Ticket ID:</label> <?php print $attendee['tid']; ?></div>
  <div><label>Quantity:</label> <?php print $attendee['quantity']; ?></div>
  <div><label>Amount paid:</label> <?php print $attendee['amount_paid']; ?></div>
  <div><label>Tax:</label> <?php print $attendee['tax']; ?></div>
  <div><label>Credit card fee:</label> <?php print $attendee['cc_fee']; ?></div>
  <div><label>Eventbrite fee:</label> <?php print $attendee['eventbrite_fee']; ?></div>
  <div><label>Discount:</label> <?php print $attendee['discount']; ?></div>
  <div><label>Currency:</label> <?php print $attendee['currency']; ?></div>
  <div><label>Order type:</label> <?php print $attendee['order_type']; ?></div>
  <div><label>Event date:</label> <?php print $attendee['event_date']; ?></div>
  <div><label>Barcode:</label> <?php print $attendee['barcode']; ?></div>
  <div><label>Created:</label> <?php print $attendee['created']; ?></div>
  <div><label>Modified:</label> <?php print $attendee['modified']; ?></div>
  <div><label>Notes:</label> <?php print $attendee['notes']; ?></div>
</fieldset>

<fieldset>
  <legend>Question and answers</legend>
  <div><label>Question ID:</label> <?php print $attendee['qid']; ?></div>
  <div><label>Question type:</label> <?php print $attendee['question_type']; ?></div>
  <div><label>Question:</label> <?php print $attendee['question']; ?></div>
  <div><label>Answer:</label> <?php print $attendee['answer_text']; ?></div>
</fieldset>

==> eventbrite_api-7.x-1.3.tar.gz: eventbrite_api/theme/attendee.tpl.php <==
<fieldset>
  <legend>Personal details</legend>
  <div><label>Attendee ID:</label> <?php print $attendee['aid']; ?></div>
  <div><label>Prefix:</label> <?php print $attendee['prefix']; ?></div>
  <div><label>First name:</label> <?php print $attendee['first_name']; ?></div>
  <div><label>Last name:</label> <?php print $attendee['last_name']; ?></div>
  <div><label>Suffix:</label> <?php print $attendee['suffix']; ?></div>
  <div><label>Address:</label> <?php print $attendee['home_address']; ?></div>
  <div><label>Address 2:</label> <?php print $attendee['home_address_2']; ?>
  </div>
  <div><label>City:</label> <?php print $attendee['home_city']; ?></div>
  <div><label>Region:</label> <?php print $attendee['home_region']; ?></div>
  <div><label>Postal code:</label> <?php print $attendee['home_postal_code']; ?>
  </div>
  <div><label>Country:</label> <?php print $attendee['home_country']; ?></div>
  <div><label>Country
      code:</label> <?php print $attendee['home_country_code']; ?></div>
  <div><label>Home phone:</label> <?php print $attendee['home_phone']; ?></div>
  <div><label>Cell/mobile phone:</label> <?php print $attendee['cell_phone']; ?>
  </div>
  <div><label>Birth date:</label> <?php print $attendee['birth_date']; ?></div>
  <div><label>Age:</label> <?php print $attendee['age']; ?></div>
  <div><label>Gender:</label> <?php print $attendee['gender']; ?></div>
</fieldset>

<fieldset>
  <legend>Work details</legend>
  <div><label>Company:</label> <?php print $attendee['company']; ?></div>
  <div><label>Address:</label> <?php print $attendee['work_address']; ?></div>
  <div><label>Address 2:</label> <?php print $attendee['work_address_2']; ?>
  </div>
  <div><label>City:</label> <?php print $attendee['work_city']; ?></div>
  <div><label>Region:</label> <?php print $attendee['work_region']; ?></div>
  <div><label>Postal code:</label> <?php print $attendee['work_postal_code']; ?>
  </div>
  <div><label>Country:</label> <?php print $attendee['work_country']; ?></div>
  <div><label>Country
      code:</label> <?php print $attendee['work_country_code']; ?></div>
  <div><label>Phone:</label> <?php print $attendee['work_phone']; ?></div>
  <div><label>Blog:</label> <?php print $attendee['blog']; ?></div>
  <div><label>Email:</label> <?php print $attendee['email']; ?></div>
  <div><label>Job title:</label> <?php print $attendee['job_title']; ?></div>
</fieldset>

<fieldset>
  <legend>Order details</legend>
  <div><label>Order ID:</label> <?php print $attendee['orid']; ?></div>
  <div><label>Event ID:</label> <?php print $attendee['eid']; ?></div>
  <div><label>Ticket ID:</label> <?php print $attendee['tid']; ?></div>
  <div><label>Quantity:</label> <?php print $attendee['quantity']; ?></div>
  <div><label>Amount paid:</label> <?php print $attendee['amount_paid']; ?>
  </div>
  <div><label>Tax:</label> <?php print $attendee['tax']; ?></div>
  <div><label>Credit card fee:</label> <?php print $attendee['cc_fee']; ?></div>
  <div><label>Eventbrite
      fee:</label> <?php print $attendee['eventbrite_fee']; ?></div>
  <div><label>Discount:</label> <?php print $attendee['discount']; ?></div>
  <div><label>Currency:</label> <?php print $attendee['currency']; ?></div>
  <div><label>Order type:</label> <?php print $attendee['order_type']; ?></div>
  <div><label>Event date:</label> <?php print $attendee['event_date']; ?></div>
  <div><label>Barcode:</label> <?php print $attendee['barcode']; ?></div>
  <div><label>Created:</label> <?php print $attendee['created']; ?></div>
  <div><label>Modified:</label> <?php print $attendee['modified']; ?></div>
  <div><label>Notes:</label> <?php print $attendee['notes']; ?></div>
</fieldset>

<fieldset>
  <legend>Question and answers</legend>
  <div><label>Question ID:</label> <?php print $attendee['qid']; ?></div>
  <div><label>Question type:</label> <?php print $attendee['question_type']; ?>
  </div>
  <div><label>Question:</label> <?php print $attendee['question']; ?></div>
  <div><label>Answer:</label> <?php print $attendee['answer_text']; ?></div>
</fieldset>
